@@ -45,14 +45,7 @@ def process_and_get_field_path_object_from_field_path(field_path_key: str, field
                     message="Cannot use an attribute selector ( ) without specifying any attribute inside it.",
                     vars_dict={'field_path_key': field_path_key, 'attributes_selectors_string': attributes_selectors_string}
                 ))
-            elif num_attributes_fields == 1:
-                # Treat a single field wrapped inside a
-                # multi-selector as a requested single field
-                return list(attributes_fields_objets.values())[0], False
-            else:
-                return attributes_fields_objets, True
-            # return attributes_fields_objets, True
-            # return attributes_fields_objets, True
+            return attributes_fields_objets, True
 
     return _get_field_object_from_field_path(field_path_key=field_path_key, fields_switch=fields_switch), False
 
@@ -66,7 +59,7 @@ def make_rendered_database_path(database_path_elements: List[DatabasePathElement
             # when other invocations of queries and operations will use the same path element instance.
             output_database_path_elements.append(path_element)
         else:
-            variable_name = path_element.element_key.replace("$key$:", "")
+            variable_name = path_element.element_key.replace('$key$:', '')
             if query_kwargs is not None:
                 matching_kwarg: Optional[Any] = query_kwargs.get(variable_name, None)
                 if matching_kwarg is not None:
@@ -140,9 +133,3 @@ def process_validate_data_and_make_single_rendered_database_path(
 
 def join_field_path_elements(field_path_elements: List[DatabasePathElement]) -> str:
     return '.'.join((f'{item.element_key}' for item in field_path_elements))
-
-def map_record_data_to_fields(data: dict, table_model: BaseField):
-    # todo: finish to implement
-    for key, item in data.items():
-        # table_model.
-        matching_field = table_model.childrens_map.get(key, None)
