@@ -21,7 +21,7 @@ class DynamoDBFirstTableModel(BaseFirstTableModel):
 class DynamoDBSecondTableModel(BaseSecondTableModel):
     accountId = BaseField(field_type=str, required=True)
 
-class InoftVocalEngineFirstTableModel(BaseFirstTableModel):
-    accountProjectUserId = BaseField(field_type=str, required=True)
-class InoftVocalEngineSecondTableModel(BaseSecondTableModel):
-    accountProjectUserId = BaseField(field_type=str, required=True)
+class ExternalDynamoDBApiFirstTableModel(BaseFirstTableModel):
+    accountProjectTableKeyId = BaseField(field_type=str, required=True)
+class ExternalDynamoDBApiSecondTableModel(BaseSecondTableModel):
+    accountProjectTableKeyId = BaseField(field_type=str, required=True)
