@@ -11,5 +11,5 @@ class BaseTableModel(TableDataModel):
 class DynamoDBTableModel(BaseTableModel):
     accountId = BaseField(field_type=str, required=True)
 
-class InoftVocalEngineTableModel(BaseTableModel):
-    accountProjectUserId = BaseField(field_type=str, required=True)
+class ExternalDynamoDBApiTableModel(BaseTableModel):
+    accountProjectTableKeyId = BaseField(field_type=str, required=True)
